@@ -287,7 +287,7 @@ struct MHD_Response
    * Mutex to synchronize access to data/size and
    * reference counts.
    */
-  pthread_mutex_t mutex;
+  MHD_mutex_ mutex;
 
   /**
    * Set to MHD_SIZE_UNKNOWN if size is not known.
@@ -637,10 +637,10 @@ struct MHD_Connection
   struct sockaddr *addr;
 
   /**
-   * Thread for this connection (if we are using
+   * Thread handle for this connection (if we are using
    * one thread per connection).
    */
-  pthread_t pid;
+  MHD_thread_handle_ pid;
 
   /**
    * Size of read_buffer (in bytes).  This value indicates
@@ -1070,19 +1070,19 @@ struct MHD_Daemon
   unsigned int worker_pool_size;
 
   /**
-   * PID of the select thread (if we have internal select)
+   * The select thread handle (if we have internal select)
    */
-  pthread_t pid;
+  MHD_thread_handle_ pid;
 
   /**
    * Mutex for per-IP connection counts.
    */
-  pthread_mutex_t per_ip_connection_mutex;
+  MHD_mutex_ per_ip_connection_mutex;
 
   /**
    * Mutex for (modifying) access to the "cleanup" connection DLL.
    */
-  pthread_mutex_t cleanup_connection_mutex;
+  MHD_mutex_ cleanup_connection_mutex;
 
   /**
    * Listen socket.
@@ -1193,6 +1193,16 @@ struct MHD_Daemon
    */
   const char *https_mem_trust;
 
+  /**
+   * Our Diffie-Hellman parameters in memory.
+   */
+  gnutls_dh_params_t https_mem_dhparams;
+
+  /**
+   * #MHD_YES if we have initialized @e https_mem_dhparams.
+   */
+  int have_dhparams;
+
   /**
    * For how many connections do we have 'tls_read_ready' set to MHD_YES?
    * Used to avoid O(n) traversal over all connections when determining
@@ -1218,7 +1228,7 @@ struct MHD_Daemon
   /**
    * A rw-lock for synchronizing access to `nnc'.
    */
-  pthread_mutex_t nnc_lock;
+  MHD_mutex_ nnc_lock;
 
   /**
    * Size of `digest_auth_random.
